@@ -5,14 +5,14 @@ use warnings;
 package MooseX::Role::MongoDB;
 # ABSTRACT: Provide MongoDB connections, databases and collections
 
-our $VERSION = '0.009'; # from MooseX-Role-MongoDB-0.009.tar.gz
+our $VERSION = '0.010';
 
 use Moose::Role 2;
 use MooseX::AttributeShortcuts;
 
 use Carp ();
-use MongoDB;
-use MongoDB::MongoClient 0.702;
+use MongoDB 1;
+use MongoDB::MongoClient 1;
 use Socket 1.96 qw/:addrinfo SOCK_RAW/; # IPv6 capable
 use String::Flogger qw/flog/;
 use Type::Params qw/compile/;
@@ -279,7 +279,7 @@ MooseX::Role::MongoDB - Provide MongoDB connections, databases and collections
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -482,12 +482,26 @@ L<https://github.com/dagolden/MooseX-Role-MongoDB>
 
 David Golden <dagolden@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Alexandr Ciornii
+=for stopwords Alexandr Ciornii David Golden Todd Bruner
+
+=over 4
+
+=item *
 
 Alexandr Ciornii <alexchorny@gmail.com>
 
+=item *
+
+David Golden <xdg@xdg.me>
+
+=item *
+
+Todd Bruner <tbruner@sandia.gov>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
